==> haskell-path-0.9.2-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path
version:              0.9.2
visibility:           public
id:                   path-0.9.2-EngiwjQhEIZ2Gqpw8NPscm
key:                  path-0.9.2-EngiwjQhEIZ2Gqpw8NPscm
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  75f722f4dd21210d3c6c9a0a25810a2c
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.0.2/site-local/path-0.9.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/path-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.2-EngiwjQhEIZ2Gqpw8NPscm
depends:
    aeson-2.1.2.0-6VydXJBWxd89BBQXwjEfAs base-4.15.1.0 deepseq-1.4.5.0
    exceptions-0.10.4 filepath-1.4.2.1
    hashable-1.4.2.0-FGfJ6SPjJOQC6UzILfUyUL template-haskell-2.17.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.9.2-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path
version:              0.9.2
visibility:           public
id:                   path-0.9.2-H4CujscixbO5Bjj14YudUF
key:                  path-0.9.2-H4CujscixbO5Bjj14YudUF
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  784a069d9ea8fafa42c94cd57b57a33e
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.0.2/site-local/path-0.9.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/path-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.2-H4CujscixbO5Bjj14YudUF
depends:
    aeson-2.1.2.1-AqJpN51jjeKBziH7oWw4y3 base-4.15.1.0 deepseq-1.4.5.0
    exceptions-0.10.4 filepath-1.4.2.1
    hashable-1.4.2.0-ACOKJtOF9viKWyhESTEaY8 template-haskell-2.17.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
